@@ -67,11 +67,10 @@ export const RestorePVCModal = withHandlePromise((props: RestorePVCModalProps) =
         },
       },
     };
-    handlePromise(k8sCreate(PersistentVolumeClaimModel, restorePVCTemplate, { ns: namespace }))
-      .then(close)
-      .catch((error) => {
-        throw error;
-      });
+    handlePromise(
+      k8sCreate(PersistentVolumeClaimModel, restorePVCTemplate, { ns: namespace }),
+      close,
+    );
   };
 
   return (
@@ -91,7 +90,7 @@ export const RestorePVCModal = withHandlePromise((props: RestorePVCModalProps) =
             />
           </FormGroup>
           <div className="ceph-restore-pvc-modal__details-section">
-            <Grid gutter="md">
+            <Grid hasGutter>
               <GridItem span={6}>
                 <div>
                   <p className="ceph-restore-pvc-modal__pvc-details">Date</p>
